'use strict';

const {  GObject, St, Clutter } = imports.gi;
const PopupMenu = imports.ui.popupMenu;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Docker = Me.imports.lib.docker;
const Tooltip = Me.imports.lib.tooltip;

var Container_Menu = GObject.registerClass(
	class Container_Menu extends PopupMenu.PopupSubMenuMenuItem {
		_init(container) {
			super._init(container.name);
			this._set_status(container.status);
		}

		_set_status(status) {
			this._icon = new St.Icon({
				icon_name: 'media-record-symbolic',
				style_class: 'stop',
				icon_size: '14'
			});

			if (status == "running") {
				this._icon.style_class = 'running';
			}

			this.actor.insert_child_at_index(this._icon, 1);
		}

		_new_action_button(icon, onClickAction, tooltip) {
			this[tooltip] = new St.Button({
				track_hover: true,
				style_class: "button",
				x_expand: true,
				x_align: Clutter.ActorAlign.CENTER
			});

			this[tooltip].child = new St.Icon({
				icon_name: icon,
				style_class: "popup-menu-icon"
			});

			this[tooltip].tooltip = new Tooltip.Tooltip({
				parent: this[tooltip],
				markup: tooltip,
				y_offset: 35
			});

			this[tooltip].connect('clicked', () => {
				onClickAction();
				this._parent._parent.close();
			});

			this._actions.actor.add_child(this[tooltip]);
		}
	}
)