'use strict';

const Gettext = imports.gettext;
const {  GObject, St, Clutter } = imports.gi;
const PopupMenu = imports.ui.popupMenu;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const ContainerMenu = Me.imports.modules.containerMenu;
const Docker = Me.imports.lib.docker;
const Tooltip = Me.imports.lib.tooltip;
const Domain = Gettext.domain(Me.metadata.uuid);
const _ = Domain.gettext;
const ngettext = Domain.ngettext;

var Container_Menu = GObject.registerClass(
	class Container_Menu extends ContainerMenu.Container_Menu {
		_init(container) {
			super._init(container);

			this._actions = new PopupMenu.PopupBaseMenuItem({reactive: false, can_focus: false});

			switch (container.status){
				case "running":
					this._new_action_button("utilities-terminal", () => {
						Docker.run_command(Docker.docker_commands.c_exec, container)
					}, _("Attach Shell"));

					this._new_action_button("media-playback-pause", () => {
						Docker.run_command(Docker.docker_commands.c_pause, container)
					}, _("Pause"));

					this._new_action_button("media-playback-stop", () => {
						Docker.run_command(Docker.docker_commands.c_stop, container)
					}, _("Stop"));

					this._new_action_button("object-rotate-left", () => {
						Docker.run_command(Docker.docker_commands.c_restart, container)
					}, _("Restart"));

				break;

				case "paused":
					this._new_action_button("media-playback-start", () => {
						Docker.run_command(Docker.docker_commands.c_unpause, container)
					}, _("Unpause"));

					this._new_action_button("media-playback-stop", () => {
						Docker.run_command(Docker.docker_commands.c_stop, container)
					}, _("Stop"));

					this._new_action_button("object-rotate-left", () => {
						Docker.run_command(Docker.docker_commands.c_restart, container)
					}, _("Restart"));
				break;

				default:
					this._new_action_button("media-playback-start", () => {
						Docker.run_command(Docker.docker_commands.c_start, container)
					}, _("Start"));

					this._new_action_button("utilities-terminal", () => {
						Docker.run_command(Docker.docker_commands.c_start_i, container)
					}, _("Start interactive"));
			}

			this._new_action_button("edit-delete", () => {
				Docker.run_command(Docker.docker_commands.c_rm, container)
			}, _("Remove"));

			this.menu.addMenuItem(this._actions);
		}
	}
)